# v1.0.1

Patch release with install fix.

- Made pywebview optional to fix install failure on Windows with Python 3.14 (pythonnet build error)
- Falls back to browser mode when pywebview is not installed
